#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-D2vxm6HA29aLTRIqoYrDo4
key:                  coinbase-pro-0.9.3.2-D2vxm6HA29aLTRIqoYrDo4
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  9b3ee475a795aaff8621c63622fb280d
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-D2vxm6HA29aLTRIqoYrDo4
depends:
    HsOpenSSL-0.11.7.9-3E6VQacZodlBxSokoSoKor
    aeson-2.2.2.0-CuqyF0GV84l91XsdnO7HOm
    aeson-casing-0.2.0.0-6xrHo6NrZ5J3vX2xiGmTly
    async-2.2.6-JvoT9znxQt2BsREADqk9DD base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-CXnEfJouJIf6V89VJilH8 exceptions-0.10.7
    http-api-data-0.6.1-5qZCNeLqP6K83PwMsEUnOv
    http-client-0.7.19-D5RaBo9PU4s8YuYDXFr2cz
    http-client-tls-0.3.6.4-IKN6IcefmTuChedx1hJelo
    http-streams-0.8.9.9-6to531s4Zgi2BCa5Ad1L34
    http-types-0.12.4-1k09WZUFwaNKy3YYy34Hwy
    io-streams-1.5.2.2-5aN2psf0TJXBW934wfachu
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-Lt0aE8CPrcjIQCbzsjcySE
    servant-0.20.3.0-9bImT2As5G46RNgphhkN9s
    servant-client-0.20.3.0-CN1IXB1BBUs2GqxFbcJkn9
    servant-client-core-0.20.3.0-Azn7miHoOvvJTJMuXYB5z4
    tasty-1.5.3-53ADb4g03a0EJGveocITRv
    tasty-hunit-0.10.2-8rzARwtGmPkFEJto2ljy5A text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-BFF4qjmFU3NBVQSa1S3DlH
    unordered-containers-0.2.20.1-owJOmMRhDW8XCXGWMsAkD
    uuid-1.3.16.1-KbjYJrvd1YaAyXdG6YrOlI
    vector-0.13.2.0-KHhvLzyWGFJKP6boEp8Bp2
    websockets-0.12.7.3-CpxONyPXMps4x39055WZQl
    wuss-2.0.1.7-CypyRtrgGo25sajyfOWhul

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

